"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useMonthEvents = void 0;

var _dayjs = _interopRequireDefault(require("dayjs"));

var _react = require("react");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useMonthEvents = (currentDay, firstDayMonday, markedDays, viewType) => {
  const eventDaysCount = viewType === 'week' ? 7 : (0, _dayjs.default)(currentDay).daysInMonth();
  const monthDays = (0, _react.useMemo)(() => new Array(eventDaysCount).fill(true), [eventDaysCount]);
  const startWeekType = firstDayMonday ? 'isoWeek' : 'week';
  const weekStartDay = (0, _dayjs.default)(currentDay).startOf(startWeekType);
  const sections = (0, _react.useMemo)(() => {
    return monthDays.map((_, index) => {
      const day = viewType === 'week' ? weekStartDay.add(index, 'day') : (0, _dayjs.default)(currentDay).date(index + 1);
      const key = day.format('YYYY-MM-DD');
      let data = [];

      if (markedDays && markedDays[key]) {
        data = markedDays[key].events;
      }

      return {
        key,
        data,
        title: day.format('ddd, MMM D')
      };
    });
  }, [currentDay, markedDays, monthDays, viewType, weekStartDay]);
  return sections;
};

exports.useMonthEvents = useMonthEvents;
//# sourceMappingURL=Events.hooks.js.map