"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAgendaEvents = void 0;

var _dayjs = _interopRequireDefault(require("dayjs"));

var _react = require("react");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useAgendaEvents = (currentMonth, events, viewType, firstDayMonday) => {
  return (0, _react.useMemo)(() => {
    const markedDays = {};
    const rangeType = viewType === 'week' ? firstDayMonday ? 'isoWeek' : 'week' : 'month';
    const firstDay = (0, _dayjs.default)(currentMonth).startOf(rangeType).startOf('day');
    const endingDay = (0, _dayjs.default)(currentMonth).endOf(rangeType).endOf('day');
    events.forEach(event => {
      if ((0, _dayjs.default)(event.endDate).isBefore((0, _dayjs.default)(event.startDate))) {
        throw new Error(`${event.name} startDate must be previous to endDate`);
      }

      if ((0, _dayjs.default)(event.endDate).isBefore(firstDay)) {
        // previous month event
        return;
      }

      if ((0, _dayjs.default)(event.startDate).isAfter(endingDay)) {
        // future month event
        return;
      }

      let currentDay = (0, _dayjs.default)(event.startDate).isBefore(firstDay) ? firstDay : (0, _dayjs.default)(event.startDate);
      const lastDay = (0, _dayjs.default)(event.endDate).isBefore(endingDay) ? (0, _dayjs.default)(event.endDate) : endingDay;

      while (currentDay.isSameOrBefore(lastDay, 'day')) {
        const dot = {
          color: event.color,
          selectedColor: event.color
        };
        const dayIndex = currentDay.format('YYYY-MM-DD');

        if (markedDays[dayIndex]) {
          var _markedDays$dayIndex$;

          (_markedDays$dayIndex$ = markedDays[dayIndex].dots) === null || _markedDays$dayIndex$ === void 0 ? void 0 : _markedDays$dayIndex$.push(dot);
          markedDays[dayIndex].events.push(event);
        } else {
          markedDays[dayIndex] = {
            dots: [dot],
            events: [event]
          };
        }

        currentDay = currentDay.add(1, 'day');
      }
    });
    return {
      markedDays
    };
  }, [currentMonth, events, firstDayMonday, viewType]);
};

exports.useAgendaEvents = useAgendaEvents;
//# sourceMappingURL=use-agenda-events.js.map