import React, { useCallback, useMemo, useRef } from 'react';
import { View } from 'react-native';
import { Month } from 'react-native-month';
import { useAgendaEvents } from '../../hooks/use-agenda-events';
import { Events } from '../Events/Events';
import { viewStyles } from './Agenda.styles';
import dayjs from 'dayjs';
import { Week } from '../Week/Week';
export const Agenda = _ref => {
  let {
    selectedDay,
    events,
    onDayPress,
    theme,
    monthTheme,
    renderSectionHeader,
    locale = 'en',
    firstDayMonday = false,
    viewType = 'month'
  } = _ref;
  const sectionListRef = useRef(null);
  const currentDay = useMemo(() => selectedDay ?? new Date(), [selectedDay]);
  const onDayPressCallback = useCallback(date => {
    var _sectionListRef$curre;

    onDayPress === null || onDayPress === void 0 ? void 0 : onDayPress(date);
    const dayIndex = viewType === 'week' ? firstDayMonday ? dayjs(date).isoWeekday() - 1 : date.getDay() : dayjs(date).date() - 1;
    (_sectionListRef$curre = sectionListRef.current) === null || _sectionListRef$curre === void 0 ? void 0 : _sectionListRef$curre.scrollToLocation({
      sectionIndex: dayIndex,
      itemIndex: 1,
      viewPosition: 0
    });
  }, [firstDayMonday, onDayPress, viewType]);
  const {
    markedDays
  } = useAgendaEvents(currentDay, events ?? [], viewType, firstDayMonday);
  return /*#__PURE__*/React.createElement(View, {
    style: [viewStyles.container, theme === null || theme === void 0 ? void 0 : theme.container]
  }, viewType === 'month' && /*#__PURE__*/React.createElement(View, {
    style: [viewStyles.monthContainer, theme === null || theme === void 0 ? void 0 : theme.monthContainer]
  }, /*#__PURE__*/React.createElement(Month, {
    month: currentDay.getMonth(),
    year: currentDay.getFullYear(),
    startDate: currentDay,
    onPress: onDayPressCallback,
    markedDays: markedDays,
    showWeekdays: true,
    locale: locale,
    firstDayMonday: firstDayMonday,
    theme: monthTheme
  })), viewType === 'week' && /*#__PURE__*/React.createElement(Week, {
    selectedDate: currentDay,
    monthTheme: monthTheme,
    firstDayMonday: firstDayMonday,
    locale: locale,
    markedDays: markedDays,
    onPress: onDayPressCallback
  }), /*#__PURE__*/React.createElement(Events, {
    currentDay: currentDay,
    markedDays: markedDays,
    ref: sectionListRef,
    renderSectionHeader: renderSectionHeader,
    viewType: viewType,
    firstDayMonday: firstDayMonday
  }));
};
//# sourceMappingURL=Agenda.js.map